"""

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import satnogsnetworkapiclient
from satnogsnetworkapiclient.model.demod_data import DemodData
globals()['DemodData'] = DemodData
from satnogsnetworkapiclient.model.observation import Observation


class TestObservation(unittest.TestCase):
    """Observation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testObservation(self):
        """Test Observation"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Observation()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
