"""

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import satnogsnetworkapiclient
from satnogsnetworkapiclient.api.api_api import ApiApi  # noqa: E501


class TestApiApi(unittest.TestCase):
    """ApiApi unit test stubs"""

    def setUp(self):
        self.api = ApiApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_api_jobs_list(self):
        """Test case for api_jobs_list

        """
        pass

    def test_api_jobs_retrieve(self):
        """Test case for api_jobs_retrieve

        """
        pass

    def test_api_observations_create(self):
        """Test case for api_observations_create

        """
        pass

    def test_api_observations_list(self):
        """Test case for api_observations_list

        """
        pass

    def test_api_observations_partial_update(self):
        """Test case for api_observations_partial_update

        """
        pass

    def test_api_observations_retrieve(self):
        """Test case for api_observations_retrieve

        """
        pass

    def test_api_observations_update(self):
        """Test case for api_observations_update

        """
        pass

    def test_api_stations_list(self):
        """Test case for api_stations_list

        """
        pass

    def test_api_stations_retrieve(self):
        """Test case for api_stations_retrieve

        """
        pass

    def test_api_transmitters_list(self):
        """Test case for api_transmitters_list

        """
        pass

    def test_api_transmitters_retrieve(self):
        """Test case for api_transmitters_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()
